==> kandis_1.4.20101005-1.tar.gz: kandis-1.4.20101005/src/Selector.h <==
#ifndef SELECTOR_H
#define SELECTOR_H

/*
  Kandis - A tea steepming timer.
  Copyright (C) 2007  Tim Teulings

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include <Lum/Base/String.h>

#include <Lum/Dlg/ActionDialog.h>

#include <Lum/Model/Action.h>
#include <Lum/Model/Number.h>
#include <Lum/Model/Selection.h>
#include <Lum/Model/String.h>
#include <Lum/Model/Table.h>

#include "Configuration.h"

typedef Lum::Model::StdRefTable<Tea,std::vector<Tea> > TeasModel;
typedef Lum::Base::Reference<TeasModel>                TeasModelRef;

class Selector : public Lum::Dlg::ActionDialog
{
private:
  Lum::Model::SizeTRef               seconds;
  TeasModelRef                       list;
  Lum::Model::SingleLineSelectionRef selection;

  Lum::Model::ActionRef              addAction;
  Lum::Model::ActionRef              editAction;
  Lum::Model::ActionRef              removeAction;
  Lum::Model::ActionRef              okAction;

  bool                               success;

public:
  Selector(Lum::Model::SizeT *seconds);
  ~Selector();

  Lum::Object* GetContent();
  void GetActions(std::vector<Lum::Dlg::ActionInfo>& actions);

  void Resync(Lum::Base::Model *model, const Lum::Base::ResyncMsg& msg);

  bool Success() const;
};

#endif

==> kandis_1.4.20101220-1.tar.gz: kandis-1.4.20101220/src/Selector.h <==
#ifndef SELECTOR_H
#define SELECTOR_H

/*
  Kandis - A tea steepming timer.
  Copyright (C) 2007  Tim Teulings

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include <Lum/Base/String.h>

#include <Lum/Dlg/ActionDialog.h>

#include <Lum/Model/Action.h>
#include <Lum/Model/Number.h>
#include <Lum/Model/Selection.h>
#include <Lum/Model/String.h>
#include <Lum/Model/Table.h>

#include "Configuration.h"

typedef Lum::Model::StdRefTable<Tea,std::vector<Tea> > TeasModel;
typedef Lum::Base::Reference<TeasModel>                TeasModelRef;

class Selector : public Lum::Dlg::ActionDialog
{
private:
  Lum::Model::NumberRef              seconds;
  TeasModelRef                       list;
  Lum::Model::SingleLineSelectionRef selection;

  Lum::Model::ActionRef              addAction;
  Lum::Model::ActionRef              editAction;
  Lum::Model::ActionRef              removeAction;
  Lum::Model::ActionRef              okAction;

  bool                               success;

public:
  Selector(Lum::Model::Number* seconds);
  ~Selector();

  Lum::Object* GetContent();
  void GetActions(std::vector<Lum::Dlg::ActionInfo>& actions);

  void Resync(Lum::Base::Model *model, const Lum::Base::ResyncMsg& msg);

  bool Success() const;
};

#endif
